Index — Football Packing 0.1 documentation

# Index

G | M | P | U

## G

get_pass_pressure() (in module packing.calculate_packing)

## M

method_1() (in module packing.calculate_packing) method_2() (in module packing.calculate_packing) method_3() (in module packing.calculate_packing) | module packing plot_packing

## P

packing module packing (class in packing) | plot_packing module plot_packing (class in plot_packing)

## U

update_method_1() (in module packing.calculate_packing)